@@ -11,17 +11,18 @@ sim_n_low <- sim_thomas_community(s_pool = 200, n_sim = 10000, sad_type = "poilo
 summary(sim_n_high)
 summary(sim_n_low)
 
-## ---- fig.width=7.2, fig.height=4.1-------------------------------------------
-par(mfrow = c(1,2))
+## ----fig.width=7.2, fig.height=4.1--------------------------------------------
+oldpar <- par(mfrow = c(1,2))
 plot(sim_n_high)
 plot(sim_n_low)
+par(oldpar)
 
 ## -----------------------------------------------------------------------------
 area <- c(0.001,0.002,0.005,0.01,0.02,0.05,0.1,0.2,0.5,1.0)
 sar_n_high <- divar(sim_n_high, prop_area = area)
 sar_n_low <- divar(sim_n_low, prop_area = area)
 
-## ---- fig.width=5, fig.height=5-----------------------------------------------
+## ----fig.width=5, fig.height=5------------------------------------------------
 names(sar_n_high)
 
 plot(m_species ~ prop_area, data = sar_n_high, type = "b", log = "xy", ylim = c(2,200),
@@ -30,23 +31,25 @@ plot(m_species ~ prop_area, data = sar_n_high, type = "b", log = "xy", ylim = c(
 lines(m_species ~ prop_area, data = sar_n_low, type = "b", col = "red")
 legend("bottomright",c("N high","N low"), col = 1:2, pch = 1)
 
-## ---- fig.width=7.2, fig.height=4.1-------------------------------------------
-par(mfrow = c(1,2))
+## ----fig.width=7.2, fig.height=4.1--------------------------------------------
+oldpar <- par(mfrow = c(1,2))
 samples_S_n_high <- sample_quadrats(sim_n_high, n_quadrats = 100,
                                         quadrat_area = 0.001, method = "random",
-                                        avoid_overlap = T)
+                                        avoid_overlap = TRUE)
 samples_S_n_low <- sample_quadrats(sim_n_low, n_quadrats = 100,
                                        quadrat_area = 0.001, method = "random",
-                                       avoid_overlap = T)
+                                       avoid_overlap = TRUE)
+par(oldpar)
 
-## ---- fig.width=7.2, fig.height=4.1-------------------------------------------
-par(mfrow = c(1,2))
+## ----fig.width=7.2, fig.height=4.1--------------------------------------------
+oldpar <- par(mfrow = c(1,2))
 samples_L_n_high <- sample_quadrats(sim_n_high, n_quadrats = 10,
                                   quadrat_area = 0.01, method = "random",
-                                  avoid_overlap = T)
+                                  avoid_overlap = TRUE)
 samples_L_n_low <- sample_quadrats(sim_n_low, n_quadrats = 10,
                                   quadrat_area = 0.01, method = "random",
-                                  avoid_overlap = T)
+                                  avoid_overlap = TRUE)
+par(oldpar)
 
 ## -----------------------------------------------------------------------------
 dim(samples_L_n_high$spec_dat)
@@ -55,7 +58,7 @@ head(samples_L_n_high$spec_dat)[,1:5]
 dim(samples_L_n_high$xy_dat)
 head(samples_L_n_high$xy_dat)
 
-## ---- message=F---------------------------------------------------------------
+## ----message=F----------------------------------------------------------------
 library(vegan)
 S_n_high <- specnumber(samples_S_n_high$spec_dat)
 S_n_low <- specnumber(samples_S_n_low$spec_dat)
@@ -72,11 +75,12 @@ div_dat_S <- data.frame(N = rep(c("N high","N low"), each = length(S_n_high)),
                         Shannon = c(Shannon_n_high, Shannon_n_low),
                         Simpson = c(Simpson_n_high, Simpson_n_low))
 
-## ---- fig.width=7.2, fig.height=3.1-------------------------------------------
-par(mfrow = c(1,3))
+## ----fig.width=7.2, fig.height=3.1--------------------------------------------
+oldpar <- par(mfrow = c(1,3))
 boxplot(S ~ N, data = div_dat_S, ylab = "Species richness")
 boxplot(Shannon ~ N, data = div_dat_S, ylab = "Shannon diversity")
 boxplot(Simpson ~ N, data = div_dat_S, ylab = "Simpson diversity")
+par(oldpar)
 
 ## -----------------------------------------------------------------------------
 mean_div_S <- aggregate(div_dat_S[,2:4], by = list(div_dat_S$N), FUN = mean)
@@ -103,11 +107,12 @@ div_dat_L <- data.frame(N = rep(c("N high","N low"), each = length(S_n_high)),
                         Shannon = c(Shannon_n_high, Shannon_n_low),
                         Simpson = c(Simpson_n_high, Simpson_n_low))
 
-## ---- fig.width=7.2, fig.height=3.1-------------------------------------------
-par(mfrow = c(1,3))
+## ----fig.width=7.2, fig.height=3.1--------------------------------------------
+oldpar <- par(mfrow = c(1,3))
 boxplot(S ~ N, data = div_dat_L, ylab = "Species richness")
 boxplot(Shannon ~ N, data = div_dat_L, ylab = "Shannon diversity")
 boxplot(Simpson ~ N, data = div_dat_L, ylab = "Simpson diversity")
+par(oldpar)
 
 ## -----------------------------------------------------------------------------
 mean_div_L <- aggregate(div_dat_L[,2:4], by = list(div_dat_L$N), FUN = mean)
